@@ -14,6 +14,7 @@
 # limitations under the License.
 #
 from .insight import Insight, InsightStateInfo
+from .insight_type_config import InsightTypeConfig, InsightTypeGenerationConfig
 from .recommendation import (
     CostProjection,
     Impact,
@@ -25,9 +26,12 @@ from .recommendation import (
     SecurityProjection,
     ValueMatcher,
 )
+from .recommender_config import RecommenderConfig, RecommenderGenerationConfig
 from .recommender_service import (
     GetInsightRequest,
+    GetInsightTypeConfigRequest,
     GetRecommendationRequest,
+    GetRecommenderConfigRequest,
     ListInsightsRequest,
     ListInsightsResponse,
     ListRecommendationsRequest,
@@ -36,11 +40,15 @@ from .recommender_service import (
     MarkRecommendationClaimedRequest,
     MarkRecommendationFailedRequest,
     MarkRecommendationSucceededRequest,
+    UpdateInsightTypeConfigRequest,
+    UpdateRecommenderConfigRequest,
 )
 
 __all__ = (
     "Insight",
     "InsightStateInfo",
+    "InsightTypeConfig",
+    "InsightTypeGenerationConfig",
     "CostProjection",
     "Impact",
     "Operation",
@@ -50,8 +58,12 @@ __all__ = (
     "RecommendationStateInfo",
     "SecurityProjection",
     "ValueMatcher",
+    "RecommenderConfig",
+    "RecommenderGenerationConfig",
     "GetInsightRequest",
+    "GetInsightTypeConfigRequest",
     "GetRecommendationRequest",
+    "GetRecommenderConfigRequest",
     "ListInsightsRequest",
     "ListInsightsResponse",
     "ListRecommendationsRequest",
@@ -60,4 +72,6 @@ __all__ = (
     "MarkRecommendationClaimedRequest",
     "MarkRecommendationFailedRequest",
     "MarkRecommendationSucceededRequest",
+    "UpdateInsightTypeConfigRequest",
+    "UpdateRecommenderConfigRequest",
 )
